**********
Exceptions
**********

.. automodule:: networkx.exception
.. currentmodule:: networkx

.. autoclass:: networkx.NetworkXException

.. autoclass:: networkx.NetworkXError

.. autoclass:: networkx.NetworkXPointlessConcept

.. autoclass:: networkx.NetworkXAlgorithmError

.. autoclass:: networkx.NetworkXUnfeasible

.. autoclass:: networkx.NetworkXNoPath

.. autoclass:: networkx.NetworkXNoCycle

.. autoclass:: networkx.NodeNotFound

.. autoclass:: networkx.HasACycle

.. autoclass:: networkx.NetworkXUnbounded

.. autoclass:: networkx.NetworkXNotImplemented

.. autoclass:: networkx.AmbiguousSolution

.. autoclass:: networkx.ExceededMaxIterations

.. autoclass:: networkx.PowerIterationFailedConvergence
